@@ -6,11 +6,13 @@ import codecs
 import json
 import logging
 import time
-from collections import defaultdict, namedtuple
+from collections import defaultdict
 from functools import wraps
 from minty import Base
+from minty.cqrs import UserInfo
 from pyramid.httpexceptions import HTTPForbidden, HTTPUnauthorized
 from redis import StrictRedis
+from typing import List, Sequence
 
 
 class SessionRetrieverError(Exception):
@@ -134,9 +136,6 @@ def session_manager_factory(infra_factory):
     return SessionRetriever(redis)
 
 
-UserInfo = namedtuple("UserInfo", "user_uuid permissions")
-
-
 def get_logged_in_user(request, logger):
     """ Get the logged in user from the given pyramid request object
 
@@ -175,11 +174,10 @@ def get_logged_in_user(request, logger):
     return user_info
 
 
-def check_user_permission(permissions, user_info):
-    """ Returns the first permission the user validates to.
-
-    Looks up every permission in the given list of permissions, and when one
-    validates, it returns that perm as a result
+def check_user_permission(
+    permissions: Sequence[str], user_info: UserInfo
+) -> bool:
+    """Returns whether the user has any of the given permissions.
 
     Args:
         permissions: List containing permissions in string format
@@ -193,17 +191,16 @@ def check_user_permission(permissions, user_info):
     # and access rights.
     #
     # This generally means someone with "admin" rights will also have
-    # the other permissions set, for instance.
+    # the other permissions set.
+
     for permission in permissions:
         try:
-            perm = user_info.permissions[permission]
+            if user_info.permissions[permission]:
+                return True
         except KeyError:
-            perm = False
+            pass
 
-        if perm:
-            break
-
-    return perm
+    return False
 
 
 def protected_route(permission="gebruiker", *args):
@@ -218,7 +215,7 @@ def protected_route(permission="gebruiker", *args):
     :return: view with `UserInfo` injected
     :rtype: wrapped view
     """
-    permission_list = [permission, *args]
+    permission_list: List[str] = [permission, *args]
 
     def protected_view_wrapper(view):
         @wraps(view)
@@ -228,12 +225,14 @@ def protected_route(permission="gebruiker", *args):
             user_info = get_logged_in_user(request, logger)
             perm = check_user_permission(permission_list, user_info)
 
-            if perm:
-                return view(request=request, user_info=user_info)
+            if not perm:
+                raise HTTPForbidden(
+                    json={
+                        "error": "You do not have permission to access this."
+                    }
+                )
 
-            raise HTTPForbidden(
-                json={"error": "You do not have permission to access this."}
-            )
+            return view(request=request, user_info=user_info)
 
         return view_wrapper
 
