@@ -8,7 +8,7 @@ from minty_pyramid.session_manager import (
     check_user_permission,
     get_logged_in_user,
 )
-from pyramid.httpexceptions import HTTPForbidden
+from pyramid.httpexceptions import HTTPBadRequest, HTTPForbidden
 
 log = logging.getLogger(__name__)
 
@@ -99,6 +99,8 @@ class JSONAPIEntityView:
 
     """
 
+    view_mapper: dict
+
     def __init__(self, context, request):
         """Initializes this object from Pyramid"""
 
@@ -179,16 +181,19 @@ class JSONAPIEntityView:
                     calldata["command_primary"]
                     and params[calldata["command_primary"]]
                 ):
+                    link = self.create_link_from_entity(
+                        entity_type=calldata["entity_type"],
+                        entity_id=params[calldata["command_primary"]],
+                    )
+
+                    if link:
+                        links_block = {"links": {"self": link}}
+                    else:
+                        links_block = {}
+
                     return {
                         "data": {
-                            "links": {
-                                "self": self.create_link_from_entity(
-                                    entity_type=calldata["entity_type"],
-                                    entity_id=params[
-                                        calldata["command_primary"]
-                                    ],
-                                )
-                            },
+                            **links_block,
                             "type": calldata["entity_type"],
                             "id": params[calldata["command_primary"]],
                         }
@@ -197,13 +202,13 @@ class JSONAPIEntityView:
                 return {"data": None}
 
         if calldata["cq"] == "query":
-            if response:
+            if response is None:
+                return {"data": None}
+            else:
                 return {
                     "data": response,
                     "links": {"self": self.request.current_route_path()},
                 }
-            else:
-                return {"data": None}
 
     def _collect_params_as_array(self, k, v, params):
         for pk, pv in self.request.params.items():
@@ -215,23 +220,58 @@ class JSONAPIEntityView:
 
                 params[v][match[1]] = pv
 
+    def _convert_value(self, request_param, domain_param_config):
+        param_key = domain_param_config["name"]
+        param_type = domain_param_config["type"]
+
+        try:
+            param_value = param_type(request_param)
+        except ValueError:
+            # View mapper defined a type, but the parameter can't be converted from
+            # string to that type.
+            raise HTTPBadRequest
+
+        return (param_key, param_value)
+
+    def _extract_request_params(self, calldata, request_params):
+        final_params = {}
+
+        for http_param_name, domain_param_name in calldata["from"][
+            "request_params"
+        ].items():
+            # Special array functionality
+            if http_param_name.endswith("[]"):
+                http_param_name = http_param_name.replace("[]", "")
+                self._collect_params_as_array(
+                    http_param_name, domain_param_name, final_params
+                )
+
+                continue
+
+            if http_param_name not in request_params:
+                continue
+
+            if isinstance(domain_param_name, dict):
+                (domain_param, converted_value) = self._convert_value(
+                    request_param=request_params[http_param_name],
+                    domain_param_config=domain_param_name,
+                )
+                final_params[domain_param] = converted_value
+            else:
+                final_params[domain_param_name] = request_params[
+                    http_param_name
+                ]
+
+        return final_params
+
     def _collect_params(self, calldata):
         """Collects parameters according to the configuration in view_mapper"""
         params = {}
 
         if "request_params" in calldata["from"]:
-            for k, v in calldata["from"]["request_params"].items():
-                # Special array functionality
-                if k.endswith("[]"):
-                    k = k.replace("[]", "")
-                    self._collect_params_as_array(k, v, params)
-
-                    continue
-
-                if k not in self.request.params:
-                    continue
-
-                params[v] = self.request.params[k]
+            params = self._extract_request_params(
+                calldata, self.request.params
+            )
 
         if "json" in calldata["from"]:
             if (
@@ -247,3 +287,10 @@ class JSONAPIEntityView:
                     params[v] = self.request.json_body[k]
 
         return params
+
+    def create_link_from_entity(
+        self, entity=None, entity_type=None, entity_id=None
+    ):
+        log.debug(
+            "create_link_from_entity called, but not overridden in view class"
+        )
